#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 prettyprinter-interp
version:              0.2.0.0
visibility:           public
id:                   prettyprinter-interp-0.2.0.0-6MqQkFnWoLx2FSTRBuWh5D
key:                  prettyprinter-interp-0.2.0.0-6MqQkFnWoLx2FSTRBuWh5D
license:              BSD-2-Clause
copyright:            (C) 2022-2023, Peter Lebbing
maintainer:           peter@digitalbrains.com
author:               Peter Lebbing
homepage:             https://github.com/DigitalBrains1/prettyprinter-interp
synopsis:             Efficient interpolation for Prettyprinter
description:
    This package provides efficient interpolation
    of @[string-interpolate](https://hackage.haskell.org/package/string-interpolate)@
    quasi quoters when used
    with @[prettyprinter](https://hackage.haskell.org/package/prettyprinter)@.

category:             Data, Text
abi:                  e2f87e6030314bbdae33bb0526a88bae
exposed:              True
exposed-modules:      Prettyprinter.Interpolate
import-dirs:          /usr/lib/ghc-9.6.6/site-local/prettyprinter-interp-0.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/prettyprinter-interp-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/prettyprinter-interp-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-prettyprinter-interp
hs-libraries:         HSprettyprinter-interp-0.2.0.0-6MqQkFnWoLx2FSTRBuWh5D
depends:
    base-4.18.2.1 prettyprinter-1.7.1-LD9ksSCydFQDqbwXyaukvW
    string-interpolate-0.3.4.0-EIThCh9XMiI9bg2OpiKWYl
    template-haskell-2.20.0.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-prettyprinter-interp/html/prettyprinter-interp.haddock

haddock-html:         /usr/share/doc/haskell-prettyprinter-interp/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

